@@ -165,14 +165,16 @@ def __add_effective_dating_constraint(blocks: ReadRequestBuildingBlocks, res: Re
         )
     else:
         blocks.constraints.append(
-            a.c.effective_start_dt.op(op1)(timestamp_to_date_string(
+            a.c.effective_start_dt
+            <= timestamp_to_date_string(
                 res.effective_dating.end_dt.seconds
-            ))
+            )
         )
         blocks.constraints.append(
-            a.c.effective_end_dt.op(op2)(timestamp_to_date_string(
+            a.c.effective_end_dt
+            >= timestamp_to_date_string(
                 res.effective_dating.start_dt.seconds
-            ))
+            )
         )
 
 
