@@ -4,15 +4,15 @@ from datetime import datetime, timedelta
 
 def to_spark_save_mode(mode: WriteMode) -> str:
     if mode == WriteMode.APPEND:
-        return 'append'
+        return "append"
 
     if mode == WriteMode.ERROR_IF_EXISTS:
-        return 'errorifexists'
+        return "errorifexists"
 
     if mode == WriteMode.IGNORE:
-        return 'ignore'
+        return "ignore"
 
-    return 'overwrite'
+    return "overwrite"
 
 
 def timestamp_to_datetime(timestamp: int):
@@ -22,10 +22,10 @@ def timestamp_to_datetime(timestamp: int):
         return datetime.utcfromtimestamp(timestamp)
 
 
-def timestamp_to_date_string(timestamp: int, f='%Y-%m-%d'):
+def timestamp_to_date_string(timestamp: int, f="%Y-%m-%d"):
     dt = timestamp_to_datetime(timestamp)
     return dt.strftime(f)
 
 
-def datetime_to_date_string(dt: datetime, f='%Y-%m-%d'):
+def datetime_to_date_string(dt: datetime, f="%Y-%m-%d"):
     return dt.strftime(f)
